@@ -415,7 +415,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
                         self.g_device_file.child.get_text(),
                         self.g_synth_num.get_value_as_int(),
                         card_info)
-            except (soundcard.SoundInitException, OSError), e:
+            except (soundcard.SoundInitException, OSError, ImportError), e:
                 self.m_app.display_sound_init_error_message(e)
                 return -1
         else: # no sound
