@@ -17,7 +17,7 @@
 
 import os
 
-import gtk, gnome
+import gtk
 import gu
 import mpd, mpd.musicdisplayer
 import abstract, const, lessonfile
@@ -27,7 +27,7 @@ import utils
 import configureoutput
 import dataparser
 
-class Teacher(abstract.LessonbasedTeacher):
+class Teacher(abstract.Teacher):
     """
     The Teacher and Gui for dictation abuses q_status a little.
     QSTATUS_NEW mean that the lessonfile is ok.
@@ -35,7 +35,7 @@ class Teacher(abstract.LessonbasedTeacher):
                questions in the same file might be useable.
     """
     def __init__(self, exname, app):
-        abstract.LessonbasedTeacher.__init__(self, exname, app)
+        abstract.Teacher.__init__(self, exname, app)
         self.lessonfileclass = lessonfile.DictationLessonfile
 
 class Gui(abstract.LessonbasedGui):
@@ -80,13 +80,10 @@ class Gui(abstract.LessonbasedGui):
         self.m_t.m_P.select_previous()
         try:
             self.display_start_of_music()
-        except mpd.MpdException, e:
-            self.exception_cleanup()
-            self.g_win.display_question_music_error_message(
-                self.m_t.m_P._idx, self.m_t.m_lessonfile, e, __file__)
-        except lessonfile.LessonfileException, e:
-            self.exception_cleanup()
-            self.g_win.display_exception_message(e, __file__)
+        except Exception, e:
+            if not self.standard_exception_handler(e, __file__,
+                    self.exception_cleanup):
+                raise e
         else:
             self.m_t.q_status = const.QSTATUS_NEW
             self.g_play.set_sensitive(True)
@@ -96,13 +93,10 @@ class Gui(abstract.LessonbasedGui):
         self.m_t.m_P.select_next()
         try:
             self.display_start_of_music()
-        except mpd.MpdException, e:
-            self.exception_cleanup()
-            self.g_win.display_question_music_error_message(
-                self.m_t.m_P._idx, self.m_t.m_lessonfile, e, __file__)
-        except lessonfile.LessonfileException, e:
-            self.exception_cleanup()
-            self.g_win.display_exception_message(e, __file__)
+        except Exception, e:
+            if not self.standard_exception_handler(e, __file__,
+                    self.exception_cleanup):
+                raise e
         else:
             self.m_t.q_status = const.QSTATUS_NEW
             self.g_play.set_sensitive(True)
@@ -116,12 +110,10 @@ class Gui(abstract.LessonbasedGui):
             return
         try:
             self.m_t.m_P.play_question()
-        except mpd.MpdException, e:
-            # since we could not play the new question, it is possible,
-            # if the user are fast, that the last question is still playing.
-            soundcard.synth.stop()
-            self.g_win.display_question_music_error_message(
-                self.m_t.m_P._idx, self.m_t.m_lessonfile, e, __file__)
+        except Exception, e:
+            if not self.standard_exception_handler(e, __file__,
+                    soundcard.synth.stop):
+                raise e
     def on_end_practise(self):
         self.m_t.end_practise()
     def show_answer(self, widget=None):
@@ -133,9 +125,9 @@ class Gui(abstract.LessonbasedGui):
         try:
             self.g_music_displayer.display(self.m_t.m_P.get_music(),
                             self.get_int('config/feta_font_size=20'))
-        except mpd.MpdException, e:
-            self.g_win.display_question_music_error_message(
-                self.m_t.m_P._idx, self.m_t.m_lessonfile, e, __file__)
+        except Exception, e:
+            if not self.standard_exception_handler(e, __file__):
+                raise e
     def _update(self):
         """
         Updates the buttons above the action_area where you have
@@ -151,10 +143,10 @@ class Gui(abstract.LessonbasedGui):
                 track.prepend_bpm(*self.m_t.m_P.get_tempo())
                 track.prepend_patch(0, self.get_int('config/preferred_instrument'))
                 soundcard.synth.play_track(track)
-            except mpd.MpdException, e:
-                soundcard.synth.stop()
-                self.g_win.display_question_music_error_message(
-                   self.m_t.m_P._idx, self.m_t.m_lessonfile, e, __file__)
+            except Exception, e:
+                if not self.standard_exception_handler(e, __file__,
+                        soundcard.synth.stop):
+                    raise e
         for i in self.g_partbox.get_children():
             i.destroy()
         # if the lessonfile was invalid, m_P could be None
@@ -181,6 +173,9 @@ class Gui(abstract.LessonbasedGui):
         else:
             self.g_partbox.set_sensitive(True)
     def display_start_of_music(self):
+        """
+        Callers must catch exceptions.
+        """
         fontsize = self.get_int('config/feta_font_size=20')
         if self.m_t.m_P.get_clue_music():
             self.g_music_displayer.display(self.m_t.m_P.get_clue_music(), fontsize)
@@ -207,13 +202,15 @@ class Gui(abstract.LessonbasedGui):
         self.action_area.set_sensitive(True)
         try:
             self.display_start_of_music()
-        except mpd.MpdException, e:
-            self.g_win.display_question_music_error_message(
-                self.m_t.m_P._idx, self.m_t.m_lessonfile, e, __file__)
-            self.m_t.q_status = const.QSTATUS_NO
-            self.g_play.set_sensitive(False)
-            self.g_show.set_sensitive(False)
-            self.g_music_displayer.clear()
+        except Exception, e:
+            def cleanup_function():
+                self.m_t.q_status = const.QSTATUS_NO
+                self.g_play.set_sensitive(False)
+                self.g_show.set_sensitive(False)
+                self.g_music_displayer.clear()
+            if not self.standard_exception_handler(e, __file__,
+                    self.cleanup_function):
+                raise e
         else:
             self.g_play.set_sensitive(True)
             self.g_show.set_sensitive(True)
