@@ -64,6 +64,20 @@ class MultiButton(gtk.Button):
             l = gtk.Label(label)
             l.show()
             self.add(l)
+        self.m_marked_wrong = False
+    def mark_wrong(self):
+        if self.m_marked_wrong:
+            return
+        self.m_marked_wrong = True
+        vbox = gtk.VBox()
+        assert len(self.get_children()) == 1
+        self.get_children()[0].reparent(vbox)
+        self.add(vbox)
+        label = gtk.Label()
+        label.set_markup("<span size='small'>%s</span>" % _("Wrong"))
+        label.show()
+        vbox.pack_start(label)
+        vbox.show()
 
 class Gui(abstract.LessonbasedGui):
     def __init__(self, teacher, window):
@@ -75,12 +89,12 @@ class Gui(abstract.LessonbasedGui):
         self.g_answer_button_box = gu.NewLineBox()
         self.practise_box.pack_start(self.g_answer_button_box)
         # The user fill the answer in this box
-        frame = gtk.Frame()
-        frame.set_shadow_type(gtk.SHADOW_IN)
-        self.practise_box.pack_start(frame, False, False)
+        self.g_answer_frame = gtk.Frame()
+        self.g_answer_frame.set_shadow_type(gtk.SHADOW_IN)
+        self.practise_box.pack_start(self.g_answer_frame, False, False)
         self.g_answer = gtk.HBox()
-        frame.add(self.g_answer)
-        frame.show_all()
+        self.g_answer_frame.add(self.g_answer)
+        self.g_answer_frame.show_all()
         # Flashbar
         self.g_flashbar = gu.FlashBar()
         self.g_flashbar.show()
@@ -151,6 +165,7 @@ class Gui(abstract.LessonbasedGui):
             if self.m_t.guess_answer(self.m_users_answer):
                 self.g_flashbar.flash(_("Correct"))
                 self.g_new.set_sensitive(True)
+                self.g_new.grab_focus()
                 self.g_guess_answer.set_sensitive(False)
                 self.g_give_up.set_sensitive(False)
                 self.g_backspace.set_sensitive(False)
@@ -159,6 +174,25 @@ class Gui(abstract.LessonbasedGui):
                         self.display_music('music')
             else:
                 self.g_flashbar.flash(_("Wrong"))
+                max_button_height = 0
+                for idx, a in enumerate(self.m_users_answer):
+                    if idx + 1 > len(self.m_t.m_P.get_question()['elements']):
+                        break
+                    if idx + 1 > len(self.m_users_answer):
+                        break
+                    if self.m_users_answer[idx] != self.m_t.m_P.get_question()['elements'][idx]['name']:
+                        self.g_answer.get_children()[idx].mark_wrong()
+                if len(self.m_users_answer) > len(self.m_t.m_P.get_question()['elements']):
+                    for btn in self.g_answer.get_children()[len(self.m_t.m_P.get_question()['elements']):]:
+                        btn.mark_wrong()
+
+                # We only recalculate the height of the answer frame
+                # if there are any buttons in it. This to avoid the frame
+                # disappearing.
+                if self.g_answer.get_children():
+                    for btn in self.g_answer.get_children():
+                        max_button_height = max(max_button_height, btn.size_request()[1])
+                    self.g_answer_frame.set_size_request(-1, max_button_height)
                 self.g_give_up.set_sensitive(True)
     def on_backspace(self, widget):
         if self.m_users_answer:
@@ -226,6 +260,7 @@ class Gui(abstract.LessonbasedGui):
         else:
             self.g_play_tonic.hide()
         self.show_hide_at_question_start_buttons()
+        self.g_flashbar.flash(_("Click 'New' to begin."))
     def on_end_practise(self):
         self.m_t.end_practise()
         self.g_backspace.set_sensitive(False)
