@@ -15,7 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-import gtk, gnome, soundcard
+import gtk, soundcard
 import gu, os
 import cfg
 
@@ -46,7 +46,7 @@ class nInstrumentSelector(gtk.VBox, cfg.ConfigUtils):
         cfg.ConfigUtils.__dict__['__init__'](self, exname)
         self.m_name = name
         hbox = gu.bHBox(self)
-        hbox.set_spacing(gnome.ui.PAD_SMALL)
+        hbox.set_spacing(gu.PAD_SMALL)
         label = gtk.Label(_('_Instrument:'))
         label.set_alignment(0.0, 0.5)
         sizegroup.add_widget(label)
@@ -109,7 +109,7 @@ class ReadOnlyInstrumentSelector(gtk.Frame, cfg.ConfigUtils):
         self.m_name = name
         self.m_on_change_callback = on_change_callback
         vbox = gtk.VBox()
-        vbox.set_border_width(gnome.ui.PAD_SMALL)
+        vbox.set_border_width(gu.PAD_SMALL)
         self.add(vbox)
         self.g_button = gu.bButton(vbox,
               soundcard.instrument_names[self.get_int(self.m_name)],
@@ -120,7 +120,7 @@ class ReadOnlyInstrumentSelector(gtk.Frame, cfg.ConfigUtils):
             self.set_int(self.m_name+'_velocity',
                       self.get_int('config/preferred_instrument_velocity'))
         hbox = gu.bHBox(vbox)
-        hbox.set_spacing(gnome.ui.PAD_SMALL)
+        hbox.set_spacing(gu.PAD_SMALL)
         label = gtk.Label(_("Velocity:"))
         label.set_alignment(1.0, 0.5)
         hbox.pack_start(label)
@@ -179,7 +179,7 @@ class InstrumentConfigurator(gtk.VBox, cfg.ConfigUtils):
         self.pack_start(self.g_override_default_instrument_checkbutton,
                         False)
         hbox = gu.bHBox(self)
-        hbox.set_spacing(gnome.ui.PAD_SMALL)
+        hbox.set_spacing(gu.PAD_SMALL)
 
         self.g_instrsel_high = InstrumentSelector(_("Highest instrument"),
                                                  exname, 'highest_instrument')
