@@ -47,6 +47,7 @@ class Menu(dict):
     children = property(get_children, set_children)
     def pformat(self, indent):
         return "%(indent)s{'name': '%(name)s',\n" \
+        "%(indent)s 'nametotranslate': _('%(name)s'),\n" \
         "%(indent)s 'children': [\n" \
         "%(children)s ]\n" \
         "%(indent)s}," %  {
@@ -414,7 +415,7 @@ class LessonFileDialogCommon(gtk.Dialog):
             (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,))
         self.m_app = app
         self.m_tree = tree
-        self.m_app.lessonfile_manager.parse()
+        self.m_app.lessonfile_manager.parse(self.m_app.m_options.debug)
         lessonfilegui.handle_lesson_id_crash(self.m_app.lessonfile_manager)
         self.m_cur_menu_path = path
         self.g_ok_button = self.add_button("gtk-ok", gtk.RESPONSE_OK)
