@@ -1033,8 +1033,7 @@ class LessonFileManager:
                     print >> sys.stderr, "add_lesson_id('%s'):" % filename, e
                     return
                 try:
-                    p = dataparser.Dataparser(predef, lessonfile_functions)
-                    p.parse_file(filename)
+                    p = parse_lesson_file_header(filename)
                 except dataparser.DataparserException, e:
                     print >> sys.stderr, "LessonFileManager.parse: Discarding lessonfile '%s' because the file contain errors:" % filename
                     print >> sys.stderr, str(e)
@@ -1114,6 +1113,21 @@ class LessonFileManager:
         """
         return [{'filename': d['filename'], 'timestr': time.strftime('%c', time.localtime(d['mtime'])), 'mtime': d['mtime']} for d in self.m_uiddb[lesson_id]]
 
+def parse_lesson_file_header(filename):
+    """
+    This function is used at program starup to get the info the
+    lessonfile_manager needs. This might not be bullet proof, but
+    it provides a 22x speedup, and that was necessary when we got
+    many lesson files.
+    """
+    r = re.compile("\\header\s{.*?}", re.MULTILINE|re.DOTALL)
+    s = file(filename, 'r').read()
+    m = r.search(s)
+    p = dataparser.Dataparser(predef, lessonfile_functions)
+    p.m_ignore_lookup_error = True
+    p.parse_string(m.group())
+    return p
+
 
 class LessonIdParser(object):
     """
