@@ -325,7 +325,7 @@ class MainWin(App, cfg.ConfigUtils):
           ('MiscMenu', None, _('_Misc exercises')),
           ('TheoryMenu', None, _('_Theory')),
           ('TheoryIntervals', None, _('_Intervals'), None, None,
-            lambda o: self.m_app.handle_href('music-theory.html')),
+            lambda o: self.m_app.handle_href('theory-intervals.html')),
           ('EditMenu', None, _("_Edit")),
           ('TreeEditor', None, _('Learning tree'), None, None,
             self.do_tree_editor),
@@ -333,9 +333,9 @@ class MainWin(App, cfg.ConfigUtils):
           ('OpenPreferencesWindow', 'gtk-preferences', None, '<ctrl>F12', None,
             self.open_preferences_window),
           ('HelpMenu', None, _('_Help')),
-          ('HelpHelp', 'gtk-help', _('_Help on current exercise'), 'F1', None,
+          ('HelpHelp', 'gtk-help', _('_Help on the current exercise'), 'F1', None,
             lambda o: self.m_app.please_help_me()),
-          ('HelpTheory', None, _('_Show music theory about the current exercise'), 'F3', None, lambda o: self.m_app.show_exercise_theory()),
+          ('HelpTheory', None, _('_Music theory on the current exercise'), 'F3', None, lambda o: self.m_app.show_exercise_theory()),
           ('HelpIndex', None, _('_User manual'), None, None,
             lambda o: self.m_app.handle_href('index.html')),
           ('HelpAllLessonFiles', None, _('All installed _lesson files'), None,
