@@ -26,11 +26,11 @@ import utils
 import const
 import soundcard
 
-class Teacher(abstract.LessonbasedTeacher):
+class Teacher(abstract.Teacher):
     OK = 1
     ERR_NO_QUESTION = 2
     def __init__(self, exname, app):
-        abstract.LessonbasedTeacher.__init__(self, exname, app)
+        abstract.Teacher.__init__(self, exname, app)
         self.lessonfileclass = lessonfile.SingAnswerLessonfile
     def new_question(self):
         # TODO This function is very similar to the one in src/idbyname.py
@@ -52,8 +52,11 @@ class Gui(abstract.LessonbasedGui):
         self.practise_box.pack_start(self.g_flashbar)
         self.g_music_displayer.clear()
         self.g_new = gu.bButton(self.action_area, _("_New"), self.new_question)
-        self.g_repeat = gu.bButton(self.action_area, _("_Repeat"), self.repeat_question)
-        self.g_repeat_arpeggio = gu.bButton(self.action_area, _("Repeat _arpeggio"), self.repeat_question_arpeggio)
+        self.g_repeat = gu.bButton(self.action_area, _("_Repeat"),
+            lambda w: self.run_exception_handled(self.m_t.m_P.play_question))
+        self.g_repeat_arpeggio = gu.bButton(self.action_area, 
+            _("Repeat _arpeggio"),
+            lambda w: self.run_exception_handled(self.m_t.m_P.play_question_arpeggio))
         self.g_play_answer = gu.bButton(self.action_area, 
                     _("_Play answer"), self.hear_answer)
         ##############
@@ -72,36 +75,26 @@ class Gui(abstract.LessonbasedGui):
             self.g_music_displayer.clear()
         try:
             g = self.m_t.new_question()
-            self.g_music_displayer.display(self.m_t.m_P.get_music(), 20)
+            if self.m_t.m_P.get_question()['music'].is_displayable():
+                self.g_music_displayer.display(self.m_t.m_P.get_music(), 20)
+            else:
+                self.g_music_displayer.clear()
             self.g_flashbar.push(self.m_t.m_P.get_question()['question_text'])
             self.m_t.m_P.play_question()
             self.g_repeat.set_sensitive(True)
             self.g_repeat_arpeggio.set_sensitive(True)
             self.g_play_answer.set_sensitive(True)
             self.g_play_answer.grab_focus()
-        except lessonfile.LessonfileException, e:
-            exception_cleanup()
-            self.g_win.display_exception_message(e, __file__)
-        except mpd.MpdException, e:
-            # Invalid key variable or music code goes here.
-            exception_cleanup()
-            self.g_win.display_question_music_error_message(
-                self.m_t.m_P._idx, self.m_t.m_lessonfile, e, __file__)
-    def repeat_question(self, widget):
-        self.m_t.m_P.play_question()
-    def repeat_question_arpeggio(self, widget):
-        self.m_t.m_P.play_question_arpeggio()
+        except Exception, e:
+            if not self.standard_exception_handler(e, __file__,
+                    exception_cleanup):
+                raise e
     def hear_answer(self, widget):
         try:
-            mpd.play_music(self.m_t.m_P.prepare_music_from_string(self.m_t.m_P.get_question(), 'answer'), 120, 0, 100)
-        except lessonfile.LessonfileException, e:
-            soundcard.synth.stop()
-            self.g_win.display_exception_message(e, __file__)
-        except mpd.MpdException, e:
-            # Invalid key variable or music code goes here.
-            soundcard.synth.stop()
-            self.g_win.display_question_music_error_message(
-                self.m_t.m_P._idx, self.m_t.m_lessonfile, e, __file__)
+            self.m_t.m_P.play_question(varname='answer')
+        except Exception, e:
+            if not self.standard_exception_handler(e, __file__):
+                raise e
         self.g_new.grab_focus()
     def update_gui_after_lessonfile_change(self):
         self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
